@@ -9,7 +9,8 @@ import os
 import pandas as pd
 import numpy as np
 import cv2
-
+import tifffile
+from flifile import FliFile
 
 
 def video_reader(file_name, type='binary', img_width=128, img_height=128, image_type=np.dtype('<f8'), s_frame=0, e_frame=-1):
@@ -29,6 +30,8 @@ def video_reader(file_name, type='binary', img_width=128, img_height=128, image_
             * 'avi': use this flag to load avi
             * 'png': use this flag to load png
             * 'fits': use this flag to load fits
+            * 'fli': use this flag to load fli
+
 
     optional_parameters:
         These parameters are used when video 'bin_type' define as binary.
@@ -67,6 +70,8 @@ def video_reader(file_name, type='binary', img_width=128, img_height=128, image_
         video = read_png(file_name)
     elif type == 'fits':
         video = read_fits(file_name)
+    elif type == 'fli':
+        video = read_fli(file_name)
     return video
 
 
@@ -128,14 +133,41 @@ def read_tif(filename):
         The video is 3D-numpy (number of frames, width, height).
 
     """
-    tiff = Image.open(filename)
-    vid_ = []
-    for i in tqdm(range(tiff.n_frames)):
-        tiff.seek(i)
-        vid_.append(np.array(tiff))
-    vid_ = np.array(vid_)
+    vid_ = tifffile.imread(filename)
 
-    # vid_ = io.imread(filename)
+    if vid_.ndim == 4:
+        frames_list = []
+        for i_ in range(vid_.shape[0]):
+            gray = cv2.cvtColor(vid_[i_, ...], cv2.COLOR_BGR2GRAY)
+            frames_list.append(gray)
+    else:
+        frames_list = vid_
+
+    frames_list = np.asarray(frames_list)
+    return frames_list
+
+
+def read_tif_iterate(filename):
+    """
+    Reading image/video with TIF format.
+
+    Parameters
+    ----------
+    file_name: str
+        Path and name of TIF image/video.
+
+    Returns
+    -------
+    @returns: NDArray
+        The video is 3D-numpy (number of frames, width, height).
+
+    """
+    vid_ = []
+    with tifffile.TiffFile(filename) as tif:
+        for page in tqdm(tif.pages):
+            image = page.asarray()
+            vid_.append(image)
+    vid_ = np.array(vid_)
 
     if vid_.ndim == 4:
         frames_list = []
@@ -197,6 +229,7 @@ def read_png(filename):
     grayscale = rgb2gray(img)
     return grayscale
 
+
 def read_fits(filename):
     """
     Reading image/video with fits format.
@@ -216,6 +249,28 @@ def read_fits(filename):
     return hdul[0].data
 
 
+def read_fli(filename):
+    """
+    Reading image/video with fli format.
+
+    Parameters
+    ----------
+    file_name: str
+        Path and name of fits image/video.
+
+    Returns
+    -------
+    @returns: NDArray
+        The video as 3D-numpy with the following shape (number of frames, width, height)
+
+    """
+    myflifile = FliFile(filename)
+    data = myflifile.getdata()
+    data_ = np.transpose(data, (2, 0, 1))
+    return data_
+
+
+
 class DirectoryType:
 
     def __init__(self, dirName, type_file):
